@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import os.path
 import subprocess
@@ -74,6 +76,8 @@ def run_opts(
         hook_stage='commit',
         show_diff_on_failure=False,
         commit_msg_filename='',
+        prepare_commit_message_source='',
+        commit_object_name='',
         checkout_type='',
         is_squash_merge='',
         rewrite_command='',
@@ -95,6 +99,8 @@ def run_opts(
         hook_stage=hook_stage,
         show_diff_on_failure=show_diff_on_failure,
         commit_msg_filename=commit_msg_filename,
+        prepare_commit_message_source=prepare_commit_message_source,
+        commit_object_name=commit_object_name,
         checkout_type=checkout_type,
         is_squash_merge=is_squash_merge,
         rewrite_command=rewrite_command,
