@@ -1,8 +1,8 @@
+from __future__ import annotations
+
 import os.path
 import shutil
-import sys
 from typing import Any
-from typing import Dict
 from unittest import mock
 
 import cfgv
@@ -173,6 +173,7 @@ def test_python_venv(tempdir_factory, store):
     )
 
 
+@xfailif_windows  # pragma: win32 no cover  # no python 2 in GHA
 def test_switch_language_versions_doesnt_clobber(tempdir_factory, store):
     # We're using the python3 repo because it prints the python version
     path = make_repo(tempdir_factory, 'python3_hooks_repo')
@@ -331,6 +332,13 @@ def test_run_a_ruby_hook(tempdir_factory, store):
     )
 
 
+def test_run_a_ruby_hook_with_user_install_set(tempdir_factory, store, tmpdir):
+    gemrc = tmpdir.join('gemrc')
+    gemrc.write('gem: --user-install\n')
+    with envcontext((('GEMRC', str(gemrc)),)):
+        test_run_a_ruby_hook(tempdir_factory, store)
+
+
 @xfailif_windows  # pragma: win32 no cover
 def test_run_versioned_ruby_hook(tempdir_factory, store):
     _test_hook_repo(
@@ -667,7 +675,7 @@ def test_additional_golang_dependencies_installed(
     path = make_repo(tempdir_factory, 'golang_hooks_repo')
     config = make_config_from_repo(path)
     # A small go package
-    deps = ['golang.org/x/example/hello']
+    deps = ['golang.org/x/example/hello@latest']
     config['hooks'][0]['additional_dependencies'] = deps
     hook = _get_hook(config, store, 'golang-hook')
     binaries = os.listdir(
@@ -688,7 +696,7 @@ def test_local_golang_additional_dependencies(store):
             'name': 'hello',
             'entry': 'hello',
             'language': 'golang',
-            'additional_dependencies': ['golang.org/x/example/hello'],
+            'additional_dependencies': ['golang.org/x/example/hello@latest'],
         }],
     }
     hook = _get_hook(config, store, 'hello')
@@ -875,7 +883,7 @@ def test_tags_on_repositories(in_tmpdir, tempdir_factory, store):
 @pytest.fixture
 def local_python_config():
     # Make a "local" hooks repo that just installs our other hooks repo
-    repo_path = get_resource_path('python_hooks_repo')
+    repo_path = get_resource_path('python3_hooks_repo')
     manifest = load_manifest(os.path.join(repo_path, C.MANIFEST_FILE))
     hooks = [
         dict(hook, additional_dependencies=[repo_path]) for hook in manifest
@@ -883,21 +891,28 @@ def local_python_config():
     return {'repo': 'local', 'hooks': hooks}
 
 
-@pytest.mark.xfail(  # pragma: win32 no cover
-    sys.platform == 'win32',
-    reason='microsoft/azure-pipelines-image-generation#989',
-)
 def test_local_python_repo(store, local_python_config):
-    hook = _get_hook(local_python_config, store, 'foo')
+    hook = _get_hook(local_python_config, store, 'python3-hook')
     # language_version should have been adjusted to the interpreter version
     assert hook.language_version != C.DEFAULT
     ret, out = _hook_run(hook, ('filename',), color=False)
     assert ret == 0
-    assert _norm_out(out) == b"['filename']\nHello World\n"
+    assert _norm_out(out) == b"3\n['filename']\nHello World\n"
+
+
+@xfailif_windows  # pragma: win32 no cover  # no python2 in GHA
+def test_local_python_repo_python2(store, local_python_config):
+    local_python_config['hooks'][0]['language_version'] = 'python2'
+    hook = _get_hook(local_python_config, store, 'python3-hook')
+    # language_version should have been adjusted to the interpreter version
+    assert hook.language_version != C.DEFAULT
+    ret, out = _hook_run(hook, ('filename',), color=False)
+    assert ret == 0
+    assert _norm_out(out) == b"2\n['filename']\nHello World\n"
 
 
 def test_default_language_version(store, local_python_config):
-    config: Dict[str, Any] = {
+    config: dict[str, Any] = {
         'default_language_version': {'python': 'fake'},
         'default_stages': ['commit'],
         'repos': [local_python_config],
@@ -914,7 +929,7 @@ def test_default_language_version(store, local_python_config):
 
 
 def test_default_stages(store, local_python_config):
-    config: Dict[str, Any] = {
+    config: dict[str, Any] = {
         'default_language_version': {'python': C.DEFAULT},
         'default_stages': ['commit'],
         'repos': [local_python_config],
@@ -1036,6 +1051,7 @@ def test_local_perl_additional_dependencies(store):
     (
         'dotnet_hooks_csproj_repo',
         'dotnet_hooks_sln_repo',
+        'dotnet_hooks_combo_repo',
     ),
 )
 def test_dotnet_hook(tempdir_factory, store, repo):
